#
# spec file for package pkcs11-helper
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pkcs11-helper
Version:        1.30.0
Release:        1.2
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
License:        BSD-3-Clause AND GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/OpenSC/OpenSC/wiki
Source0:        https://github.com/OpenSC/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.bz2
Source2:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)

%description
pkcs11-helper allows using multiple PKCS#11 providers at the same
time and selecting keys by id, label or certificate subject.
Besides it covers the following topics: * Handling card removal
and card insert events:
* Handling card re-insert to a different slot
* Supporting session expiration serialization
* and much more All this is possible using a simple API.

%package -n libpkcs11-helper1
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
Group:          System/Libraries
# dropped empty package with 1.30.0, required by openvpn
Provides:       %{name} = %{version}

%description -n libpkcs11-helper1
pkcs11-helper allows using multiple PKCS#11 providers at the same time,
selecting keys by id, label or certificate subject, handling card
removal and card insert events, handling card re-insert to a different
slot, supporting session expiration serialization and much more, all
using a simple API.

%package devel
Summary:        Helper Library for the Use with Smart Cards and the PKCS#11 API
Group:          Development/Libraries/C and C++
Requires:       libpkcs11-helper1 = %{version}

%description devel
pkcs11-helper allows using multiple PKCS#11 providers at the same time,
selecting keys by id, label or certificate subject, handling card
removal and card insert events, handling card re-insert to a different
slot, supporting session expiration serialization and much more, all
using a simple API.

%prep
%autosetup -p1

%build
#autoreconf -fvi
# We use only openssl - disable all other engines
%configure \
  --disable-static \
  --enable-doc \
  --docdir=%{_docdir}/%{name} \
  --disable-crypto-engine-gnutls \
  --disable-crypto-engine-nss \
  --disable-crypto-engine-polarssl \
  --disable-crypto-engine-mbedtls \
  --disable-crypto-engine-cryptoapi
%make_build

%install
%make_install
cp -a AUTHORS ChangeLog THANKS %{buildroot}%{_docdir}/%{name}/
find %{buildroot} -type f -name "*.la" -delete -print
# installed via macro
find %{buildroot}%{_docdir} -type f -name "COPYING*" -delete -print

%ldconfig_scriptlets -n libpkcs11-helper1

%files -n libpkcs11-helper1
%license COPYING*
%{_libdir}/libpkcs11-helper.so.*
%{_mandir}/man8/*%{ext_man}
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/api

%files devel
%license COPYING*
%doc %{_docdir}/%{name}/api
%{_includedir}/pkcs11-helper-1.0
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/*.m4

%changelog
* Sun Feb 11 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.30.0:
  * core: add dynamic loader provider attribute
  * openssl: support DSA in libressl-3.5.0
  * openssl: fix openssl_ex_data_dup prototype
- get rid of almost empty pkcs11-helper package
* Fri Oct 14 2022 Jason Sikes <jsikes@suse.com>
- Update to 1.29.0:
  * build: do not fail if slot evnets are disabled, thanks to Fabrice Fontaine.
  * core: do not assume standard objects supported by provider.
  * openssl: set back key into EVP for openssl-3 to work, thanks to apollo13.
* Sun Jan 23 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.28.0:
  * build and OpenSSL compatibility fixes
  * certificate: add methods accept full mechanism
  * core: load provider library as private
  * add API to support adding properties
  * core: add PKCS11H_PROVIDER_PROPERTY_PROVIDER_DESTRUCT_HOOK
  * session: respect login required token flag
  * certificate: respect always authenticate flag
* Mon Dec 13 2021 Dirk Müller <dmueller@suse.com>
- update to 1.27.0:
  * core: handle PIN expiration after C_Login as C_Login may take a while
  * core: return explict success when plugin&play and no threading and no
    safefork, thanks to Tunnelblick
  * openssl: build with openssl ec disabled
  * openssl: support RSA_NO_PADDING padding, thanks to Selva Nair
  * core: reduce mutex lock scope of add/remove provider, thanks to Frank Morgner
  * core: improve the fork fixup sequence
* Thu Aug  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_datadir}/aclocal: when we might switch to pkgconf instead
  of pkg-config, nothing in the build root is 'accidentally' owning
  this directory for us.
* Tue Jan 29 2019 sbrabec@suse.com
- Update to version 1.25.1:
  * core: build with threading disabled, do not attempt to
    initialize provider with fork mode is not safe. Too many
    providers do not follow the PKCS#11 spec.
  * openssl: rework support 1.1.
* Wed Jul 19 2017 jengelh@inai.de
- RPM group fix.
- Remove --with-pic which is only for static libs.
* Tue Jul 18 2017 tchvatal@suse.com
- Version update to 1.22:
  * Support openssl-1.1
  * bunch of small fixes
- Remove obsolete patch pkcs11-helper-1.06-pkgconfig.patch
* Sat Dec 20 2014 p.drouand@gmail.com
- Update to version 1.11
  + openssl: support generic pkey.
  + openssl: add dsa support.
  + openssl: add ecdsa support.
- Changes from version 1.10
  + PolarSSL crypto engine by Adriaan de Jong
  + build: --disable-crypto-engine-win32 renamed to
  - -disable-crypto-engine-cryptoapi
  + api: PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_WIN32 renamed to
    PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_CRYPTOAPI.
  + api: PKCS11H_ENGINE_CRYPTO_WIN32 renamed to
    PKCS11H_ENGINE_CRYPTO_CRYPTOAPI
- pkcs11-helper has a new home; update homepage and source Url
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Tue Jul 10 2012 sbrabec@suse.cz
- Update to version 1.09:
  * Do not retry if CKR_BUFFER_TOO_SMALL and none NULL target.
  * Do not attempt to logout if uninitialized.
  * Use OpenSSL engine's rsa_priv_enc instead of rsa_sign.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Apr  9 2009 sbrabec@suse.cz
- Updated to version 1.07:
  * Minor portability fix.
- Don't call autoreconf on older products.
* Wed Mar 18 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies and pkgconfig file
* Mon Sep  8 2008 sbrabec@suse.cz
- Updated to version 1.06:
  * Portability fixes.
* Tue Apr 15 2008 ro@suse.de
- added baselibs.conf file for multilib support
* Wed Apr  2 2008 sbrabec@suse.cz
- Updated to version 1.05:
  * Export pkcs11h_logout().
  * Added NSS crypto engine.
  * Added new slotevent mode (poll vs fetch).
  * Add more invalid characters to serialization string.
  * Fix openssl decrypt return code.
* Wed Aug  8 2007 sbrabec@suse.cz
- Fixed dependencies to allow to install more instances of library.
* Wed Aug  1 2007 sbrabec@suse.cz
- New SuSE package, version 1.03.
